@@ -67,6 +67,8 @@ class SFTPToWasbOperator(BaseOperator):
         When wasb_overwrite_object is True, it will overwrite the existing data.
         If set to False, the operation might fail with
         ResourceExistsError in case a blob object already exists.
+    :param create_container: Attempt to create the target container prior to uploading the blob. This is
+        useful if the target container may not exist yet. Defaults to False.
     """
 
     template_fields: Sequence[str] = ("sftp_source_path", "container_name", "blob_prefix")
@@ -82,6 +84,7 @@ class SFTPToWasbOperator(BaseOperator):
         load_options: Optional[Dict] = None,
         move_object: bool = False,
         wasb_overwrite_object: bool = False,
+        create_container: bool = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -94,6 +97,7 @@ class SFTPToWasbOperator(BaseOperator):
         self.wasb_conn_id = wasb_conn_id
         self.load_options = load_options or {"overwrite": wasb_overwrite_object}
         self.move_object = move_object
+        self.create_container = create_container
 
     def dry_run(self) -> None:
         super().dry_run()
@@ -183,7 +187,13 @@ class SFTPToWasbOperator(BaseOperator):
                     self.container_name,
                     file.blob_name,
                 )
-                wasb_hook.load_file(tmp.name, self.container_name, file.blob_name, **self.load_options)
+                wasb_hook.load_file(
+                    tmp.name,
+                    self.container_name,
+                    file.blob_name,
+                    self.create_container,
+                    **self.load_options,
+                )
 
                 uploaded_files.append(file.sftp_file_path)
 
